import base64
import requests

import dots
from dots import token


class Transaction():

    @classmethod
    def create(cls, user_id, amount, reciept=None, breakdown=None, notes=None, allow_debit=False):

        json = {
            'user_id': user_id,
            'amount': amount,
            'reciept': reciept,
            'breakdown': breakdown,
            'notes': notes,
            'allow_debit': allow_debit
        }

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.post(
            dots.api_base + '/transactions/create', json=json, headers=headers)
        data = response.json()

        if data['success']:
            return data['transaction']
        else:
            raise Exception(data['message'])

    @classmethod
    def get(cls, transaction_id):

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.get(
            dots.api_base + '/transactions/get/transaction/' + transaction_id, headers=headers)
        data = response.json()

        if data['success']:
            return data['transaction']
        else:
            raise Exception(data['message'])



import base64
import requests

import dots
from dots import token


class User():

    @classmethod
    def create(cls, email, country_code, phone_number, first_name, last_name, username=None):

        json = {
            'email': email,
            'country_code': country_code,
            'phone_number': phone_number,
            'first_name': first_name,
            'last_name': last_name,
        }

        if username is not None:
            json['username'] = username

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.post(
            dots.api_base + '/users/create', json=json, headers=headers)

        data = response.json()

        if (data['success']):
            return data['verification_id']
        else:
            response.raise_for_status()

    @classmethod
    def get(cls, user_id):

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.get(
            dots.api_base + '/users/get/' + user_id, headers=headers)
        data = response.json()

        if data['success']:
            return data['user']
        else:
            response.raise_for_status()

    @classmethod
    def send_verification_token(cls, verification_id):

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.post(
            dots.api_base + '/users/send_verification_token', json={'verification_id': verification_id}, headers=headers)
        data = response.json()

        if data['success']:
            return True
        else:
            print(data.message)
            response.raise_for_status()

    @classmethod
    def verify_user(cls, verification_id, verification_token):

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.post(
            dots.api_base + '/users/verify_user', json={'verification_id': verification_id, verification_token: verification_token}, headers=headers)
        data = response.json()

        if data['success']:
            return data['user']['id']
        else:
            return False

    @classmethod
    def get_wallet(cls, user_id):

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.get(
            dots.api_base + '/users/wallet/get/' + user_id, headers=headers)
        data = response.json()

        if data['success']:
            return data['wallet']
        else:
            response.raise_for_status()

    @classmethod
    def generate_refill_link(cls, user_id):

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.post(
            dots.api_base + '/users/wallet/refill', json={'user_id': user_id}, headers=headers)
        data = response.json()

        if data['success'] == True:
            return data['link']
        elif data['success'] == False:
            raise Exception(data.message)
        else:
            response.raise_for_status()

    @classmethod
    def generate_payout_link(cls, user_id):

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.post(
            dots.api_base + '/users/wallet/payout', json={'user_id': user_id}, headers=headers)
        data = response.json()

        if data['success'] == True:
            return data['link']
        elif data['success'] == False:
            raise Exception(data.message)
        else:
            response.raise_for_status()

    @classmethod
    def get_transactions(cls, user_id, page=None):

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        query = ''
        if page is not None:
            query = '?page=' + str(page)

        response = requests.get(
            dots.api_base + '/transactions/get/user/' + user_id + query, headers=headers)
        data = response.json()

        if data['success']:
            return data['transactions']
        else:
            response.raise_for_status()



import base64
import requests

import dots
from dots import token

class Invoice():

    @classmethod
    def create(cls, amount, expires_in=None, items=None, breakdown=None, requested_information=None):
        
        json = {
            'amount': amount,
        }

        if expires_in is not None:
            json['expires_in'] = expires_in
        
        if items is not None:
            json['items'] = items
        
        if breakdown is not None:
            json['breakdown'] = breakdown
        
        if requested_information is not None:
            json['requested_information'] = requested_information

        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.post(dots.api_base + '/invoice/create', json=json, headers=headers)

        data = response.json()

        if data['success']:
            return data['invoice']
        else:
            response.raise_for_status()

    @classmethod
    def get(cls, invoice_id):
        
        headers = {
            'Authorization': 'Basic ' + token.get_auth_token()
        }

        response = requests.get(dots.api_base + '/invoice/get/' + invoice_id, headers=headers)
        data = response.json()

        if data['success']:
            return data['invoice']
        else:
            response.raise_for_status()



import base64

import dots

def get_auth_token():
    
    if dots.client_id == None or dots.api_key == None:
        raise AssertionError('api_key and/or client_id not set')

    token = base64.b64encode(bytes(dots.client_id + ':' + dots.api_key, 'utf-8')).decode('utf-8')
    return token
